# EvContactForm

## Installation

- Run `composer require evoluted/contact-form` to pull in the latest version

See ev_contact_form.php for example configuration

- Copy to `App/Config/Plugin/ev_contact_form.php`

```

// This file would be found at /app/Config/Plugin/ev_contact_form.php
$config = [
	'EvContactForm' => [
		'enable_filters' => false, // Enables admin filtering on contact form results. Handy if you have multiple contact forms.

		'forms' => [
			'Enquiry Form' => [
				'template' => false, // Name of your custom view in app/View/Elements
				'use_inline_errors' => false, // toggle to true to show error messages under each invalid form element
				'user_email_notification' => array( //Set up user notification emails
					'from' => array(
						'email' => 'admin@evoluted.net',
						'name' => 'Evoluted CMS'
					),
					'subject' => 'Enquiry from evoluted CMS'
				),
				'form' => [
					'class' => ''
				],
				'flash' => [ // for more details refer to http://book.cakephp.org/2.0/en/core-libraries/components/sessions.html#SessionComponent::setFlash
					'success' => [
						// The Flash message template
						'element' => 'success',
						'message' => 'Your message has been sent, we will get back to you shortly',
						'params' => [],
						// The array key found under the ‘Flash’ key in the session, defaults as 'flash'
						'key' => 'ev_contact_form'
					],
					'error' => [
						// The Flash message template
						'element' => 'fail',
						'message' => 'There was an issue saving your message, please try again',
						'params' => [],
						// The array key found under the ‘Flash’ key in the session, defaults as 'flash'
						'key' => 'ev_contact_form'
					],
					'validation' => [
						// The Flash message template
						'element' => 'fail',
						'message' => 'Please check you have filled out all the required fields',
						'params' => [],
						// The array key found under the ‘Flash’ key in the session, defaults as 'flash'
						'key' => 'ev_contact_form'
					]
				],
				'name_label' => 'name',
				'fields' => [
					'name' => [
						'type' => 'text',
						'label' => 'Name',
						'admin-label' => 'Name',
						'class' => 'form-control',
						'div' => 'form-group required',
						'validate' => [
							'required' => [
								'rule' => 'notBlank',
								'message' => 'Please supply your name'
							]
						]
					],
					'email' => [
						'type' => 'email',
						'label' => 'Email',
						'admin-label' => 'Email',
						'class' => 'form-control email',
						'div' => 'form-group required',
						'validate' => [
							'required' => [
								'rule' => 'notBlank',
								'message' => 'Please supply a valid email address'
							],
							'email' => [
								'rule' => 'email',
								'message' => 'Please supply a valid email address'
							]
						]
					],
					'phone' => [
						'admin-label' => 'Phone',
						'type' => 'tel',
						'label' => 'Phone',
						'class' => 'form-control phone',
						'div' => 'form-group',
					],
					'company' => [
						'type' => 'text',
						'label' => 'Company',
						'admin-label' => 'Company',
						'class' => 'form-control',
						'div' => 'form-group required',
						'validate' => [
							'required' => [
								'rule' => 'notBlank',
								'message' => 'Please supply your company name'
							]
						]
					],
					'postcode' => [
						'type' => 'text',
						'label' => 'Postcode',
						'admin-label' => 'Postcode',
						'class' => 'form-control',
						'div' => 'form-group required',
						'validate' => [
							'required' => [
								'rule' => 'notBlank',
								'message' => 'Please supply your postcode'
							]
						]
					],
					'file' => [
						'admin-label' => 'File',
						'type' => 'file',
						'label' => 'Attach File',
						'class' => 'form-control file',
						'div' => 'form-group'
					],
					'subject' => [
						'admin-label' => 'Subject',
						'type' => 'text',
						'label' => 'Subject',
						'class' => 'form-control',
						'div' => 'form-group',
					],
					'message' => [
						'type' => 'textarea',
						'label' => 'Message',
						'admin-label' => 'Message',
						'class' => 'form-control',
						'div' => 'form-group required',
						'validate' => [
							'required' => [
								'rule' => 'notBlank',
								'message' => 'Please supply your message'
							]
						]
					],
					'origin' => [
						'type' => 'hidden',
						'admin-type' => 'string',
						'label' => 'Regarding',
						'admin-label' => 'Origin',
						'class' => 'enquiry-origin',
						'div' => 'input'
					],
				],
				'submit' => [
					'class' => 'btn btn-default',
					'div' => 'input',
					'type' => 'button',
					'id' => 'enquiry_submit',
					'escape' => false,
					'label' => '&nbsp;',
					'button_text' => 'Send',
				],
				'success_redirect' => [
					'plugin' => false,
					'controller' => 'pages',
					'action' => 'view',
					1
				]
			],
		],
	]
];

```

### /app/Config/bootstrap

	'EvContactForm'=>array(
		'routes'=>true,
		'bootstrap'=>true
	)

## Setup

To setup the database use the CakeDC Migrations plugin. To run the migrations and setup the database run:-

	Console/cake Migrations.migration run all --plugin EvContactForm

Go to /admin/contact-form/form and create the contact forms, as many as you have defined in config. You will need the ID for the next stage.

## Usage

### Controller

Add to $components.

	'EvContactForm.InjectContactForm'

Add to `$helpers`.

	'EvContactForm.ShowContactForm'

In view action in controller where you want to show & process contact form

	$this->InjectContactForm->display($id, 'enquiry');

Where $id is the ID of the contact form you have created in admin, and 'enquiry' is the name you choose. It posts using this, so make it unique.

### View

Paste the following into the view template where you would like the form to display:

	<?= $this->ShowContactForm->display('enquiry') ?>

To style your contact form, copy `contact_form.ctp` from `EvContactForm/View/Elements` to your Apps `View/Elements` directory.

#### Flash and Validation Errors

There are two options to choose from when showing Flash messages and form validation errors and can be controlled by toggling the `use_inline_errors` flag on each form.

The flag should be left as `false` to display a default Flash message above the form containing an unordered list of validation errors.

Toggling the field to `true` will stop the Flash message and will show form validation messages underneath each failing form element.

### Success and Redirects
Once a successful submission has been made you can have the system redirect the user to another page. This is done by editing the `success_redirect` parameter in the plugin config. This currently accepts:
- A standard CakePHP route array where you define controller, action etc
- A literal URL
- "true", which will redirect back to the page the form is on
- An array featuring the key `internal_title` which will look up and redirect to the page with the matching internal title (will throw a NotFoundException if it doesn't exist)

### File Uploads
From version 2.2.8.0 you can add a file upload option to your contact form. This simply needs a file field type, and an example of its usage can be found in the `config-fullsample.php` file. Documents are then made viewable in read-only mode when viewing the contact form response in the admin area.

You can also attach these files to the notification email by enabling the `EvContactForm.attach_files_to_notification_email` setting. There is also an optional `EvContactForm.notification_email_attachments_max_filesize` setting that you can use to define the maximum combined filesize of the attachments; this is useful to ensure that nothing too big is attached to the email (it doesn't affect what can be uploaded to the enquiry). The notification email will contain links to the attachments when `EvContactForm.attach_files_to_notification_email` is set to `true` as well as attempting to attach them.

### Sending user emails
If you want to notify the user of the enquiry they have made by email then you need to add an extra setting to the form config.

	'user_email_notification' => true,

By default the subject is the site title and the email is sent from the site title with the admin's email address set up in the CMS site settings. If you would like to customise the subject or who the email is being sent from then you can use the following setting:

	'user_email_notification' => array(
		'from' => array(
			'email' => 'admin@evoluted.net',
			'name' => 'Evoluted CMS'
		),
		'subject' => 'Enquiry from evoluted CMS'
	),

# Conversion success tracking

A field has been added to the site settings (conversion success code) for storing Google tracking code and is echoed on form success:

	echo Configure::read('SiteSetting.tracking.conversion_success_code');

